@@ -1,26 +1,21 @@
-from sentry_sdk.hub import Hub
 from sentry_sdk.scope import Scope
 from sentry_sdk.transport import Transport, HttpTransport
 from sentry_sdk.client import Client
-from sentry_sdk._init_implementation import init
 
 from sentry_sdk.api import *  # noqa
 
 from sentry_sdk.consts import VERSION  # noqa
 
-from sentry_sdk.crons import monitor  # noqa
-from sentry_sdk.tracing import trace  # noqa
-
 __all__ = [  # noqa
     "Hub",
     "Scope",
     "Client",
     "Transport",
     "HttpTransport",
-    "init",
     "integrations",
-    "trace",
     # From sentry_sdk.api
+    "init",
+    "add_attachment",
     "add_breadcrumb",
     "capture_event",
     "capture_exception",
@@ -30,6 +25,9 @@ __all__ = [  # noqa
     "flush",
     "get_baggage",
     "get_client",
+    "get_global_scope",
+    "get_isolation_scope",
+    "get_current_scope",
     "get_current_span",
     "get_traceparent",
     "is_initialized",
@@ -46,6 +44,13 @@ __all__ = [  # noqa
     "set_user",
     "start_span",
     "start_transaction",
+    "trace",
+    "monitor",
+    "logger",
+    "start_session",
+    "end_session",
+    "set_transaction_name",
+    "update_current_span",
 ]
 
 # Initialize the debug support after everything is loaded
@@ -53,3 +58,6 @@ from sentry_sdk.debug import init_debug_support
 
 init_debug_support()
 del init_debug_support
+
+# circular imports
+from sentry_sdk.hub import Hub
