@@ -8,6 +8,7 @@ from importlib import import_module
 from typing import TYPE_CHECKING, List, Dict, cast, overload
 import warnings
 
+import sentry_sdk
 from sentry_sdk._compat import PY37, check_uwsgi_thread_support
 from sentry_sdk.utils import (
     AnnotatedValue,
@@ -22,6 +23,8 @@ from sentry_sdk.utils import (
     handle_in_app,
     is_gevent,
     logger,
+    get_before_send_log,
+    has_logs_enabled,
 )
 from sentry_sdk.serializer import serialize
 from sentry_sdk.tracing import trace
@@ -46,7 +49,6 @@ from sentry_sdk.profiler.transaction_profiler import (
 )
 from sentry_sdk.scrubber import EventScrubber
 from sentry_sdk.monitor import Monitor
-from sentry_sdk.spotlight import setup_spotlight
 
 if TYPE_CHECKING:
     from typing import Any
@@ -110,7 +112,7 @@ def _get_options(*args, **kwargs):
         rv["environment"] = os.environ.get("SENTRY_ENVIRONMENT") or "production"
 
     if rv["debug"] is None:
-        rv["debug"] = env_to_bool(os.environ.get("SENTRY_DEBUG", "False"), strict=True)
+        rv["debug"] = env_to_bool(os.environ.get("SENTRY_DEBUG"), strict=True) or False
 
     if rv["server_name"] is None and hasattr(socket, "gethostname"):
         rv["server_name"] = socket.gethostname()
@@ -215,8 +217,8 @@ class BaseClient:
         # type: (*Any, **Any) -> Optional[str]
         return None
 
-    def _capture_experimental_log(self, scope, log):
-        # type: (Scope, Log) -> None
+    def _capture_experimental_log(self, log):
+        # type: (Log) -> None
         pass
 
     def capture_session(self, *args, **kwargs):
@@ -382,7 +384,8 @@ class _Client(BaseClient):
                     )
 
             self.log_batcher = None
-            if experiments.get("enable_logs", False):
+
+            if has_logs_enabled(self.options):
                 from sentry_sdk._log_batcher import LogBatcher
 
                 self.log_batcher = LogBatcher(capture_func=_capture_envelope)
@@ -428,6 +431,10 @@ class _Client(BaseClient):
                 )
 
             if self.options.get("spotlight"):
+                # This is intentionally here to prevent setting up spotlight
+                # stuff we don't need unless spotlight is explicitly enabled
+                from sentry_sdk.spotlight import setup_spotlight
+
                 self.spotlight = setup_spotlight(self.options)
                 if not self.options["dsn"]:
                     sample_all = lambda *_args, **_kwargs: 1.0
@@ -893,12 +900,13 @@ class _Client(BaseClient):
 
         return return_value
 
-    def _capture_experimental_log(self, current_scope, log):
-        # type: (Scope, Log) -> None
-        logs_enabled = self.options["_experiments"].get("enable_logs", False)
-        if not logs_enabled:
+    def _capture_experimental_log(self, log):
+        # type: (Optional[Log]) -> None
+        if not has_logs_enabled(self.options) or log is None:
             return
-        isolation_scope = current_scope.get_isolation_scope()
+
+        current_scope = sentry_sdk.get_current_scope()
+        isolation_scope = sentry_sdk.get_isolation_scope()
 
         log["attributes"]["sentry.sdk.name"] = SDK_INFO["name"]
         log["attributes"]["sentry.sdk.version"] = SDK_INFO["version"]
@@ -927,6 +935,21 @@ class _Client(BaseClient):
             elif propagation_context is not None:
                 log["trace_id"] = propagation_context.trace_id
 
+        # The user, if present, is always set on the isolation scope.
+        if isolation_scope._user is not None:
+            for log_attribute, user_attribute in (
+                ("user.id", "id"),
+                ("user.name", "username"),
+                ("user.email", "email"),
+            ):
+                if (
+                    user_attribute in isolation_scope._user
+                    and log_attribute not in log["attributes"]
+                ):
+                    log["attributes"][log_attribute] = isolation_scope._user[
+                        user_attribute
+                    ]
+
         # If debug is enabled, log the log to the console
         debug = self.options.get("debug", False)
         if debug:
@@ -934,9 +957,10 @@ class _Client(BaseClient):
                 f'[Sentry Logs] [{log.get("severity_text")}] {log.get("body")}'
             )
 
-        before_send_log = self.options["_experiments"].get("before_send_log")
+        before_send_log = get_before_send_log(self.options)
         if before_send_log is not None:
             log = before_send_log(log, {})
+
         if log is None:
             return
 
