@@ -3,7 +3,10 @@ from enum import Enum
 from typing import TYPE_CHECKING
 
 # up top to prevent circular import due to integration import
-DEFAULT_MAX_VALUE_LENGTH = 1024
+# This is more or less an arbitrary large-ish value for now, so that we allow
+# pretty long strings (like LLM prompts), but still have *some* upper limit
+# until we verify that removing the trimming completely is safe.
+DEFAULT_MAX_VALUE_LENGTH = 100_000
 
 DEFAULT_MAX_STACK_FRAMES = 100
 DEFAULT_ADD_FULL_STACK = False
@@ -97,6 +100,17 @@ FALSE_VALUES = [
 ]
 
 
+class SPANTEMPLATE(str, Enum):
+    DEFAULT = "default"
+    AI_AGENT = "ai_agent"
+    AI_TOOL = "ai_tool"
+    AI_CHAT = "ai_chat"
+
+    def __str__(self):
+        # type: () -> str
+        return self.value
+
+
 class INSTRUMENTER:
     SENTRY = "sentry"
     OTEL = "otel"
@@ -108,209 +122,263 @@ class SPANDATA:
     See: https://develop.sentry.dev/sdk/performance/span-data-conventions/
     """
 
-    AI_FREQUENCY_PENALTY = "ai.frequency_penalty"
-    """
-    Used to reduce repetitiveness of generated tokens.
-    Example: 0.5
-    """
-
-    AI_PRESENCE_PENALTY = "ai.presence_penalty"
-    """
-    Used to reduce repetitiveness of generated tokens.
-    Example: 0.5
-    """
-
-    AI_INPUT_MESSAGES = "ai.input_messages"
-    """
-    The input messages to an LLM call.
-    Example: [{"role": "user", "message": "hello"}]
-    """
-
-    AI_MODEL_ID = "ai.model_id"
-    """
-    The unique descriptor of the model being execugted
-    Example: gpt-4
-    """
-
-    AI_METADATA = "ai.metadata"
-    """
-    Extra metadata passed to an AI pipeline step.
-    Example: {"executed_function": "add_integers"}
-    """
-
-    AI_TAGS = "ai.tags"
-    """
-    Tags that describe an AI pipeline step.
-    Example: {"executed_function": "add_integers"}
-    """
-
-    AI_STREAMING = "ai.streaming"
-    """
-    Whether or not the AI model call's repsonse was streamed back asynchronously
-    Example: true
-    """
-
-    AI_TEMPERATURE = "ai.temperature"
-    """
-    For an AI model call, the temperature parameter. Temperature essentially means how random the output will be.
-    Example: 0.5
-    """
-
-    AI_TOP_P = "ai.top_p"
-    """
-    For an AI model call, the top_p parameter. Top_p essentially controls how random the output will be.
-    Example: 0.5
-    """
-
-    AI_TOP_K = "ai.top_k"
-    """
-    For an AI model call, the top_k parameter. Top_k essentially controls how random the output will be.
-    Example: 35
-    """
-
-    AI_FUNCTION_CALL = "ai.function_call"
-    """
-    For an AI model call, the function that was called. This is deprecated for OpenAI, and replaced by tool_calls
-    """
-
-    AI_TOOL_CALLS = "ai.tool_calls"
-    """
-    For an AI model call, the function that was called. This is deprecated for OpenAI, and replaced by tool_calls
-    """
-
-    AI_TOOLS = "ai.tools"
-    """
-    For an AI model call, the functions that are available
-    """
-
-    AI_RESPONSE_FORMAT = "ai.response_format"
-    """
-    For an AI model call, the format of the response
-    """
-
-    AI_LOGIT_BIAS = "ai.logit_bias"
-    """
-    For an AI model call, the logit bias
-    """
-
-    AI_PREAMBLE = "ai.preamble"
-    """
-    For an AI model call, the preamble parameter.
-    Preambles are a part of the prompt used to adjust the model's overall behavior and conversation style.
-    Example: "You are now a clown."
-    """
-
-    AI_RAW_PROMPTING = "ai.raw_prompting"
-    """
-    Minimize pre-processing done to the prompt sent to the LLM.
-    Example: true
-    """
-    AI_RESPONSES = "ai.responses"
-    """
-    The responses to an AI model call. Always as a list.
-    Example: ["hello", "world"]
-    """
-
-    AI_SEED = "ai.seed"
-    """
-    The seed, ideally models given the same seed and same other parameters will produce the exact same output.
-    Example: 123.45
-    """
-
     AI_CITATIONS = "ai.citations"
     """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
     References or sources cited by the AI model in its response.
     Example: ["Smith et al. 2020", "Jones 2019"]
     """
 
     AI_DOCUMENTS = "ai.documents"
     """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
     Documents or content chunks used as context for the AI model.
     Example: ["doc1.txt", "doc2.pdf"]
     """
 
-    AI_SEARCH_QUERIES = "ai.search_queries"
-    """
-    Queries used to search for relevant context or documents.
-    Example: ["climate change effects", "renewable energy"]
-    """
-
-    AI_SEARCH_RESULTS = "ai.search_results"
-    """
-    Results returned from search queries for context.
-    Example: ["Result 1", "Result 2"]
-    """
-
-    AI_GENERATION_ID = "ai.generation_id"
-    """
-    Unique identifier for the completion.
-    Example: "gen_123abc"
-    """
-
-    AI_SEARCH_REQUIRED = "ai.is_search_required"
-    """
-    Boolean indicating if the model needs to perform a search.
-    Example: true
-    """
-
     AI_FINISH_REASON = "ai.finish_reason"
     """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_RESPONSE_FINISH_REASONS instead.
+
     The reason why the model stopped generating.
     Example: "length"
     """
 
+    AI_FREQUENCY_PENALTY = "ai.frequency_penalty"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_FREQUENCY_PENALTY instead.
+
+    Used to reduce repetitiveness of generated tokens.
+    Example: 0.5
+    """
+
+    AI_FUNCTION_CALL = "ai.function_call"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_RESPONSE_TOOL_CALLS instead.
+
+    For an AI model call, the function that was called. This is deprecated for OpenAI, and replaced by tool_calls
+    """
+
+    AI_GENERATION_ID = "ai.generation_id"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_RESPONSE_ID instead.
+
+    Unique identifier for the completion.
+    Example: "gen_123abc"
+    """
+
+    AI_INPUT_MESSAGES = "ai.input_messages"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_MESSAGES instead.
+
+    The input messages to an LLM call.
+    Example: [{"role": "user", "message": "hello"}]
+    """
+
+    AI_LOGIT_BIAS = "ai.logit_bias"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    For an AI model call, the logit bias
+    """
+
+    AI_METADATA = "ai.metadata"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    Extra metadata passed to an AI pipeline step.
+    Example: {"executed_function": "add_integers"}
+    """
+
+    AI_MODEL_ID = "ai.model_id"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_MODEL or GEN_AI_RESPONSE_MODEL instead.
+
+    The unique descriptor of the model being executed.
+    Example: gpt-4
+    """
+
     AI_PIPELINE_NAME = "ai.pipeline.name"
     """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_PIPELINE_NAME instead.
+
     Name of the AI pipeline or chain being executed.
     Example: "qa-pipeline"
     """
 
+    AI_PREAMBLE = "ai.preamble"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    For an AI model call, the preamble parameter.
+    Preambles are a part of the prompt used to adjust the model's overall behavior and conversation style.
+    Example: "You are now a clown."
+    """
+
+    AI_PRESENCE_PENALTY = "ai.presence_penalty"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_PRESENCE_PENALTY instead.
+
+    Used to reduce repetitiveness of generated tokens.
+    Example: 0.5
+    """
+
+    AI_RAW_PROMPTING = "ai.raw_prompting"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    Minimize pre-processing done to the prompt sent to the LLM.
+    Example: true
+    """
+
+    AI_RESPONSE_FORMAT = "ai.response_format"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    For an AI model call, the format of the response
+    """
+
+    AI_RESPONSES = "ai.responses"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_RESPONSE_TEXT instead.
+
+    The responses to an AI model call. Always as a list.
+    Example: ["hello", "world"]
+    """
+
+    AI_SEARCH_QUERIES = "ai.search_queries"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    Queries used to search for relevant context or documents.
+    Example: ["climate change effects", "renewable energy"]
+    """
+
+    AI_SEARCH_REQUIRED = "ai.is_search_required"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    Boolean indicating if the model needs to perform a search.
+    Example: true
+    """
+
+    AI_SEARCH_RESULTS = "ai.search_results"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    Results returned from search queries for context.
+    Example: ["Result 1", "Result 2"]
+    """
+
+    AI_SEED = "ai.seed"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_SEED instead.
+
+    The seed, ideally models given the same seed and same other parameters will produce the exact same output.
+    Example: 123.45
+    """
+
+    AI_STREAMING = "ai.streaming"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_RESPONSE_STREAMING instead.
+
+    Whether or not the AI model call's response was streamed back asynchronously
+    Example: true
+    """
+
+    AI_TAGS = "ai.tags"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
+    Tags that describe an AI pipeline step.
+    Example: {"executed_function": "add_integers"}
+    """
+
+    AI_TEMPERATURE = "ai.temperature"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_TEMPERATURE instead.
+
+    For an AI model call, the temperature parameter. Temperature essentially means how random the output will be.
+    Example: 0.5
+    """
+
     AI_TEXTS = "ai.texts"
     """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
     Raw text inputs provided to the model.
     Example: ["What is machine learning?"]
     """
 
+    AI_TOP_K = "ai.top_k"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_TOP_K instead.
+
+    For an AI model call, the top_k parameter. Top_k essentially controls how random the output will be.
+    Example: 35
+    """
+
+    AI_TOP_P = "ai.top_p"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_TOP_P instead.
+
+    For an AI model call, the top_p parameter. Top_p essentially controls how random the output will be.
+    Example: 0.5
+    """
+
+    AI_TOOL_CALLS = "ai.tool_calls"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_RESPONSE_TOOL_CALLS instead.
+
+    For an AI model call, the function that was called. This is deprecated for OpenAI, and replaced by tool_calls
+    """
+
+    AI_TOOLS = "ai.tools"
+    """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_REQUEST_AVAILABLE_TOOLS instead.
+
+    For an AI model call, the functions that are available
+    """
+
     AI_WARNINGS = "ai.warnings"
     """
+    .. deprecated::
+        This attribute is deprecated. Use GEN_AI_* attributes instead.
+
     Warning messages generated during model execution.
     Example: ["Token limit exceeded"]
     """
 
-    DB_NAME = "db.name"
-    """
-    The name of the database being accessed. For commands that switch the database, this should be set to the target database (even if the command fails).
-    Example: myDatabase
-    """
-
-    DB_USER = "db.user"
-    """
-    The name of the database user used for connecting to the database.
-    See: https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/semantic_conventions/database.md
-    Example: my_user
-    """
-
-    DB_OPERATION = "db.operation"
-    """
-    The name of the operation being executed, e.g. the MongoDB command name such as findAndModify, or the SQL keyword.
-    See: https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/semantic_conventions/database.md
-    Example: findAndModify, HMSET, SELECT
-    """
-
-    DB_SYSTEM = "db.system"
-    """
-    An identifier for the database management system (DBMS) product being used.
-    See: https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/semantic_conventions/database.md
-    Example: postgresql
-    """
-
-    DB_MONGODB_COLLECTION = "db.mongodb.collection"
-    """
-    The MongoDB collection being accessed within the database.
-    See: https://github.com/open-telemetry/semantic-conventions/blob/main/docs/database/mongodb.md#attributes
-    Example: public.users; customers
-    """
-
     CACHE_HIT = "cache.hit"
     """
     A boolean indicating whether the requested data was found in the cache.
@@ -329,22 +397,254 @@ class SPANDATA:
     Example: template.cache.some_item.867da7e2af8e6b2f3aa7213a4080edb3
     """
 
-    NETWORK_PEER_ADDRESS = "network.peer.address"
+    CODE_FILEPATH = "code.filepath"
     """
-    Peer address of the network connection - IP address or Unix domain socket name.
-    Example: 10.1.2.80, /tmp/my.sock, localhost
+    The source code file name that identifies the code unit as uniquely as possible (preferably an absolute file path).
+    Example: "/app/myapplication/http/handler/server.py"
     """
 
-    NETWORK_PEER_PORT = "network.peer.port"
+    CODE_FUNCTION = "code.function"
     """
-    Peer port number of the network connection.
-    Example: 6379
+    The method or function name, or equivalent (usually rightmost part of the code unit's name).
+    Example: "server_request"
     """
 
-    HTTP_QUERY = "http.query"
+    CODE_LINENO = "code.lineno"
     """
-    The Query string present in the URL.
-    Example: ?foo=bar&bar=baz
+    The line number in `code.filepath` best representing the operation. It SHOULD point within the code unit named in `code.function`.
+    Example: 42
+    """
+
+    CODE_NAMESPACE = "code.namespace"
+    """
+    The "namespace" within which `code.function` is defined. Usually the qualified class or module name, such that `code.namespace` + some separator + `code.function` form a unique identifier for the code unit.
+    Example: "http.handler"
+    """
+
+    DB_MONGODB_COLLECTION = "db.mongodb.collection"
+    """
+    The MongoDB collection being accessed within the database.
+    See: https://github.com/open-telemetry/semantic-conventions/blob/main/docs/database/mongodb.md#attributes
+    Example: public.users; customers
+    """
+
+    DB_NAME = "db.name"
+    """
+    The name of the database being accessed. For commands that switch the database, this should be set to the target database (even if the command fails).
+    Example: myDatabase
+    """
+
+    DB_OPERATION = "db.operation"
+    """
+    The name of the operation being executed, e.g. the MongoDB command name such as findAndModify, or the SQL keyword.
+    See: https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/semantic_conventions/database.md
+    Example: findAndModify, HMSET, SELECT
+    """
+
+    DB_SYSTEM = "db.system"
+    """
+    An identifier for the database management system (DBMS) product being used.
+    See: https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/semantic_conventions/database.md
+    Example: postgresql
+    """
+
+    DB_USER = "db.user"
+    """
+    The name of the database user used for connecting to the database.
+    See: https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/semantic_conventions/database.md
+    Example: my_user
+    """
+
+    GEN_AI_AGENT_NAME = "gen_ai.agent.name"
+    """
+    The name of the agent being used.
+    Example: "ResearchAssistant"
+    """
+
+    GEN_AI_CHOICE = "gen_ai.choice"
+    """
+    The model's response message.
+    Example: "The weather in Paris is rainy and overcast, with temperatures around 57°F"
+    """
+
+    GEN_AI_OPERATION_NAME = "gen_ai.operation.name"
+    """
+    The name of the operation being performed.
+    Example: "chat"
+    """
+
+    GEN_AI_PIPELINE_NAME = "gen_ai.pipeline.name"
+    """
+    Name of the AI pipeline or chain being executed.
+    Example: "qa-pipeline"
+    """
+
+    GEN_AI_RESPONSE_FINISH_REASONS = "gen_ai.response.finish_reasons"
+    """
+    The reason why the model stopped generating.
+    Example: "COMPLETE"
+    """
+
+    GEN_AI_RESPONSE_ID = "gen_ai.response.id"
+    """
+    Unique identifier for the completion.
+    Example: "gen_123abc"
+    """
+
+    GEN_AI_RESPONSE_MODEL = "gen_ai.response.model"
+    """
+    Exact model identifier used to generate the response
+    Example: gpt-4o-mini-2024-07-18
+    """
+
+    GEN_AI_RESPONSE_STREAMING = "gen_ai.response.streaming"
+    """
+    Whether or not the AI model call's response was streamed back asynchronously
+    Example: true
+    """
+
+    GEN_AI_RESPONSE_TEXT = "gen_ai.response.text"
+    """
+    The model's response text messages.
+    Example: ["The weather in Paris is rainy and overcast, with temperatures around 57°F", "The weather in London is sunny and warm, with temperatures around 65°F"]
+    """
+
+    GEN_AI_RESPONSE_TOOL_CALLS = "gen_ai.response.tool_calls"
+    """
+    The tool calls in the model's response.
+    Example: [{"name": "get_weather", "arguments": {"location": "Paris"}}]
+    """
+
+    GEN_AI_REQUEST_AVAILABLE_TOOLS = "gen_ai.request.available_tools"
+    """
+    The available tools for the model.
+    Example: [{"name": "get_weather", "description": "Get the weather for a given location"}, {"name": "get_news", "description": "Get the news for a given topic"}]
+    """
+
+    GEN_AI_REQUEST_FREQUENCY_PENALTY = "gen_ai.request.frequency_penalty"
+    """
+    The frequency penalty parameter used to reduce repetitiveness of generated tokens.
+    Example: 0.1
+    """
+
+    GEN_AI_REQUEST_MAX_TOKENS = "gen_ai.request.max_tokens"
+    """
+    The maximum number of tokens to generate in the response.
+    Example: 2048
+    """
+
+    GEN_AI_REQUEST_MESSAGES = "gen_ai.request.messages"
+    """
+    The messages passed to the model. The "content" can be a string or an array of objects.
+    Example: [{role: "system", "content: "Generate a random number."}, {"role": "user", "content": [{"text": "Generate a random number between 0 and 10.", "type": "text"}]}]
+    """
+
+    GEN_AI_REQUEST_MODEL = "gen_ai.request.model"
+    """
+    The model identifier being used for the request.
+    Example: "gpt-4-turbo"
+    """
+
+    GEN_AI_REQUEST_PRESENCE_PENALTY = "gen_ai.request.presence_penalty"
+    """
+    The presence penalty parameter used to reduce repetitiveness of generated tokens.
+    Example: 0.1
+    """
+
+    GEN_AI_REQUEST_SEED = "gen_ai.request.seed"
+    """
+    The seed, ideally models given the same seed and same other parameters will produce the exact same output.
+    Example: "1234567890"
+    """
+
+    GEN_AI_REQUEST_TEMPERATURE = "gen_ai.request.temperature"
+    """
+    The temperature parameter used to control randomness in the output.
+    Example: 0.7
+    """
+
+    GEN_AI_REQUEST_TOP_K = "gen_ai.request.top_k"
+    """
+    Limits the model to only consider the K most likely next tokens, where K is an integer (e.g., top_k=20 means only the 20 highest probability tokens are considered).
+    Example: 35
+    """
+
+    GEN_AI_REQUEST_TOP_P = "gen_ai.request.top_p"
+    """
+    The top_p parameter used to control diversity via nucleus sampling.
+    Example: 1.0
+    """
+
+    GEN_AI_SYSTEM = "gen_ai.system"
+    """
+    The name of the AI system being used.
+    Example: "openai"
+    """
+
+    GEN_AI_TOOL_DESCRIPTION = "gen_ai.tool.description"
+    """
+    The description of the tool being used.
+    Example: "Searches the web for current information about a topic"
+    """
+
+    GEN_AI_TOOL_INPUT = "gen_ai.tool.input"
+    """
+    The input of the tool being used.
+    Example: {"location": "Paris"}
+    """
+
+    GEN_AI_TOOL_NAME = "gen_ai.tool.name"
+    """
+    The name of the tool being used.
+    Example: "web_search"
+    """
+
+    GEN_AI_TOOL_OUTPUT = "gen_ai.tool.output"
+    """
+    The output of the tool being used.
+    Example: "rainy, 57°F"
+    """
+
+    GEN_AI_TOOL_TYPE = "gen_ai.tool.type"
+    """
+    The type of tool being used.
+    Example: "function"
+    """
+
+    GEN_AI_USAGE_INPUT_TOKENS = "gen_ai.usage.input_tokens"
+    """
+    The number of tokens in the input.
+    Example: 150
+    """
+
+    GEN_AI_USAGE_INPUT_TOKENS_CACHED = "gen_ai.usage.input_tokens.cached"
+    """
+    The number of cached tokens in the input.
+    Example: 50
+    """
+
+    GEN_AI_USAGE_OUTPUT_TOKENS = "gen_ai.usage.output_tokens"
+    """
+    The number of tokens in the output.
+    Example: 250
+    """
+
+    GEN_AI_USAGE_OUTPUT_TOKENS_REASONING = "gen_ai.usage.output_tokens.reasoning"
+    """
+    The number of tokens used for reasoning in the output.
+    Example: 75
+    """
+
+    GEN_AI_USAGE_TOTAL_TOKENS = "gen_ai.usage.total_tokens"
+    """
+    The total number of tokens used (input + output).
+    Example: 400
+    """
+
+    GEN_AI_USER_MESSAGE = "gen_ai.user.message"
+    """
+    The user message passed to the model.
+    Example: "What's the weather in Paris?"
     """
 
     HTTP_FRAGMENT = "http.fragment"
@@ -359,6 +659,12 @@ class SPANDATA:
     Example: GET
     """
 
+    HTTP_QUERY = "http.query"
+    """
+    The Query string present in the URL.
+    Example: ?foo=bar&bar=baz
+    """
+
     HTTP_STATUS_CODE = "http.response.status_code"
     """
     The HTTP status code as an integer.
@@ -376,21 +682,39 @@ class SPANDATA:
     The message's identifier.
     """
 
-    MESSAGING_MESSAGE_RETRY_COUNT = "messaging.message.retry.count"
-    """
-    Number of retries/attempts to process a message.
-    """
-
     MESSAGING_MESSAGE_RECEIVE_LATENCY = "messaging.message.receive.latency"
     """
     The latency between when the task was enqueued and when it was started to be processed.
     """
 
+    MESSAGING_MESSAGE_RETRY_COUNT = "messaging.message.retry.count"
+    """
+    Number of retries/attempts to process a message.
+    """
+
     MESSAGING_SYSTEM = "messaging.system"
     """
     The messaging system's name, e.g. `kafka`, `aws_sqs`
     """
 
+    NETWORK_PEER_ADDRESS = "network.peer.address"
+    """
+    Peer address of the network connection - IP address or Unix domain socket name.
+    Example: 10.1.2.80, /tmp/my.sock, localhost
+    """
+
+    NETWORK_PEER_PORT = "network.peer.port"
+    """
+    Peer port number of the network connection.
+    Example: 6379
+    """
+
+    PROFILER_ID = "profiler_id"
+    """
+    Label identifying the profiler id that the span occurred in. This should be a string.
+    Example: "5249fbada8d5416482c2f6e47e337372"
+    """
+
     SERVER_ADDRESS = "server.address"
     """
     Name of the database host.
@@ -416,30 +740,6 @@ class SPANDATA:
     Example: 16456
     """
 
-    CODE_FILEPATH = "code.filepath"
-    """
-    The source code file name that identifies the code unit as uniquely as possible (preferably an absolute file path).
-    Example: "/app/myapplication/http/handler/server.py"
-    """
-
-    CODE_LINENO = "code.lineno"
-    """
-    The line number in `code.filepath` best representing the operation. It SHOULD point within the code unit named in `code.function`.
-    Example: 42
-    """
-
-    CODE_FUNCTION = "code.function"
-    """
-    The method or function name, or equivalent (usually rightmost part of the code unit's name).
-    Example: "server_request"
-    """
-
-    CODE_NAMESPACE = "code.namespace"
-    """
-    The "namespace" within which `code.function` is defined. Usually the qualified class or module name, such that `code.namespace` + some separator + `code.function` form a unique identifier for the code unit.
-    Example: "http.handler"
-    """
-
     THREAD_ID = "thread.id"
     """
     Identifier of a thread from where the span originated. This should be a string.
@@ -452,12 +752,6 @@ class SPANDATA:
     Example: "MainThread"
     """
 
-    PROFILER_ID = "profiler_id"
-    """
-    Label identifying the profiler id that the span occurred in. This should be a string.
-    Example: "5249fbada8d5416482c2f6e47e337372"
-    """
-
 
 class SPANSTATUS:
     """
@@ -497,6 +791,13 @@ class OP:
     FUNCTION = "function"
     FUNCTION_AWS = "function.aws"
     FUNCTION_GCP = "function.gcp"
+    GEN_AI_CHAT = "gen_ai.chat"
+    GEN_AI_EMBEDDINGS = "gen_ai.embeddings"
+    GEN_AI_EXECUTE_TOOL = "gen_ai.execute_tool"
+    GEN_AI_HANDOFF = "gen_ai.handoff"
+    GEN_AI_PIPELINE = "gen_ai.pipeline"
+    GEN_AI_INVOKE_AGENT = "gen_ai.invoke_agent"
+    GEN_AI_RESPONSES = "gen_ai.responses"
     GRAPHQL_EXECUTE = "graphql.execute"
     GRAPHQL_MUTATION = "graphql.mutation"
     GRAPHQL_PARSE = "graphql.parse"
@@ -519,16 +820,9 @@ class OP:
     MIDDLEWARE_STARLITE = "middleware.starlite"
     MIDDLEWARE_STARLITE_RECEIVE = "middleware.starlite.receive"
     MIDDLEWARE_STARLITE_SEND = "middleware.starlite.send"
-    OPENAI_CHAT_COMPLETIONS_CREATE = "ai.chat_completions.create.openai"
-    OPENAI_EMBEDDINGS_CREATE = "ai.embeddings.create.openai"
     HUGGINGFACE_HUB_CHAT_COMPLETIONS_CREATE = (
         "ai.chat_completions.create.huggingface_hub"
     )
-    LANGCHAIN_PIPELINE = "ai.pipeline.langchain"
-    LANGCHAIN_RUN = "ai.run.langchain"
-    LANGCHAIN_TOOL = "ai.tool.langchain"
-    LANGCHAIN_AGENT = "ai.agent.langchain"
-    LANGCHAIN_CHAT_COMPLETIONS_CREATE = "ai.chat_completions.create.langchain"
     QUEUE_PROCESS = "queue.process"
     QUEUE_PUBLISH = "queue.publish"
     QUEUE_SUBMIT_ARQ = "queue.submit.arq"
@@ -620,6 +914,8 @@ class ClientConstructor:
         custom_repr=None,  # type: Optional[Callable[..., Optional[str]]]
         add_full_stack=DEFAULT_ADD_FULL_STACK,  # type: bool
         max_stack_frames=DEFAULT_MAX_STACK_FRAMES,  # type: Optional[int]
+        enable_logs=False,  # type: bool
+        before_send_log=None,  # type: Optional[Callable[[Log, Hint], Optional[Log]]]
     ):
         # type: (...) -> None
         """Initialize the Sentry SDK with the given parameters. All parameters described here can be used in a call to `sentry_sdk.init()`.
@@ -990,7 +1286,6 @@ class ClientConstructor:
 
         :param profile_session_sample_rate:
 
-
         :param enable_tracing:
 
         :param propagate_traces:
@@ -1001,6 +1296,14 @@ class ClientConstructor:
 
         :param instrumenter:
 
+        :param enable_logs: Set `enable_logs` to True to enable the SDK to emit
+            Sentry logs. Defaults to False.
+
+        :param before_send_log: An optional function to modify or filter out logs
+            before they're sent to Sentry. Any modifications to the log in this
+            function will be retained. If the function returns None, the log will
+            not be sent to Sentry.
+
         :param _experiments:
         """
         pass
@@ -1026,4 +1329,4 @@ DEFAULT_OPTIONS = _get_default_options()
 del _get_default_options
 
 
-VERSION = "2.29.1"
+VERSION = "2.35.0"
