@@ -2,10 +2,11 @@ import io
 import json
 import mimetypes
 
-from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.session import Session
 from sentry_sdk.utils import json_dumps, capture_internal_exceptions
 
+from typing import TYPE_CHECKING
+
 if TYPE_CHECKING:
     from typing import Any
     from typing import Optional
@@ -78,7 +79,11 @@ class Envelope:
     ):
         # type: (...) -> None
         self.add_item(
-            Item(payload=PayloadRef(json=profile_chunk), type="profile_chunk")
+            Item(
+                payload=PayloadRef(json=profile_chunk),
+                type="profile_chunk",
+                headers={"platform": profile_chunk.get("platform", "python")},
+            )
         )
 
     def add_checkin(
@@ -259,7 +264,7 @@ class Item:
     def data_category(self):
         # type: (...) -> EventDataCategory
         ty = self.headers.get("type")
-        if ty == "session":
+        if ty == "session" or ty == "sessions":
             return "session"
         elif ty == "attachment":
             return "attachment"
@@ -267,6 +272,8 @@ class Item:
             return "transaction"
         elif ty == "event":
             return "error"
+        elif ty == "log":
+            return "log"
         elif ty == "client_report":
             return "internal"
         elif ty == "profile":
