@@ -125,21 +125,41 @@ _MIN_VERSIONS = {
     "ariadne": (0, 20),
     "arq": (0, 23),
     "asyncpg": (0, 23),
-    "boto3": (1, 12),  # this is actually the botocore version
+    "beam": (2, 12),
+    "boto3": (1, 12),  # botocore
     "bottle": (0, 12),
     "celery": (4, 4, 7),
+    "chalice": (1, 16, 0),
     "clickhouse_driver": (0, 2, 0),
+    "cohere": (5, 4, 0),
     "django": (1, 8),
+    "dramatiq": (1, 9),
     "falcon": (1, 4),
-    "flask": (0, 10),
+    "fastapi": (0, 79, 0),
+    "flask": (1, 1, 4),
     "gql": (3, 4, 1),
     "graphene": (3, 3),
+    "grpc": (1, 32, 0),  # grpcio
+    "huggingface_hub": (0, 22),
+    "langchain": (0, 0, 210),
+    "launchdarkly": (9, 8, 0),
+    "loguru": (0, 7, 0),
+    "openai": (1, 0, 0),
+    "openai_agents": (0, 0, 19),
+    "openfeature": (0, 7, 1),
+    "quart": (0, 16, 0),
     "ray": (2, 7, 0),
+    "requests": (2, 0, 0),
     "rq": (0, 6),
     "sanic": (0, 8),
     "sqlalchemy": (1, 2),
+    "starlette": (0, 16),
+    "starlite": (1, 48),
+    "statsig": (0, 55, 3),
     "strawberry": (0, 209, 5),
     "tornado": (6, 0),
+    "typer": (0, 15),
+    "unleash": (6, 0, 1),
 }
 
 
