@@ -1,4 +1,4 @@
-from sentry_sdk._types import TYPE_CHECKING
+import sentry_sdk
 from sentry_sdk.consts import OP
 from sentry_sdk.integrations.redis.consts import SPAN_ORIGIN
 from sentry_sdk.integrations.redis.modules.caches import (
@@ -12,8 +12,8 @@ from sentry_sdk.integrations.redis.utils import (
 )
 from sentry_sdk.tracing import Span
 from sentry_sdk.utils import capture_internal_exceptions
-import sentry_sdk
 
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from collections.abc import Callable
@@ -37,17 +37,25 @@ def patch_redis_async_pipeline(
 
         with sentry_sdk.start_span(
             op=OP.DB_REDIS,
-            description="redis.pipeline.execute",
+            name="redis.pipeline.execute",
             origin=SPAN_ORIGIN,
         ) as span:
             with capture_internal_exceptions():
+                try:
+                    command_seq = self._execution_strategy._command_queue
+                except AttributeError:
+                    if is_cluster:
+                        command_seq = self._command_stack
+                    else:
+                        command_seq = self.command_stack
+
                 set_db_data_fn(span, self)
                 _set_pipeline_data(
                     span,
                     is_cluster,
                     get_command_args_fn,
                     False if is_cluster else self.is_transaction,
-                    self._command_stack if is_cluster else self.command_stack,
+                    command_seq,
                 )
 
             return await old_execute(self, *args, **kwargs)
@@ -78,7 +86,7 @@ def patch_redis_async_client(cls, is_cluster, set_db_data_fn):
         if cache_properties["is_cache_key"] and cache_properties["op"] is not None:
             cache_span = sentry_sdk.start_span(
                 op=cache_properties["op"],
-                description=cache_properties["description"],
+                name=cache_properties["description"],
                 origin=SPAN_ORIGIN,
             )
             cache_span.__enter__()
@@ -87,7 +95,7 @@ def patch_redis_async_client(cls, is_cluster, set_db_data_fn):
 
         db_span = sentry_sdk.start_span(
             op=db_properties["op"],
-            description=db_properties["description"],
+            name=db_properties["description"],
             origin=SPAN_ORIGIN,
         )
         db_span.__enter__()
