@@ -4,7 +4,8 @@ from threading import Thread, Lock
 
 import sentry_sdk
 from sentry_sdk.utils import logger
-from sentry_sdk._types import TYPE_CHECKING
+
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from typing import Optional
@@ -117,7 +118,3 @@ class Monitor:
     def kill(self):
         # type: () -> None
         self._running = False
-
-    def __del__(self):
-        # type: () -> None
-        self.kill()
