@@ -11,7 +11,8 @@ from sentry_sdk.utils import (
     safe_repr,
     strip_string,
 )
-from sentry_sdk._types import TYPE_CHECKING
+
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from types import TracebackType
@@ -62,6 +63,14 @@ def add_global_repr_processor(processor):
     global_repr_processors.append(processor)
 
 
+sequence_types = [Sequence, Set]  # type: List[type]
+
+
+def add_repr_sequence_type(ty):
+    # type: (type) -> None
+    sequence_types.append(ty)
+
+
 class Memo:
     __slots__ = ("_ids", "_objs")
 
@@ -331,7 +340,7 @@ def serialize(event, **kwargs):
             return rv_dict
 
         elif not isinstance(obj, serializable_str_types) and isinstance(
-            obj, (Set, Sequence)
+            obj, tuple(sequence_types)
         ):
             rv_list = []
 
